@@ -25,17 +25,8 @@
 
 #include "tinyxml2.h"
 
-#ifndef TINYXML2_MAJOR_VERSION_GE_6
-#if TINYXML2_MAJOR_VERSION >= 6
-  #define TINYXML2_MAJOR_VERSION_GE_6
-#endif
-#endif
-
 #ifdef _WIN32
-  static const char pathSeparator = '\\';
   #define snprintf _snprintf
-#else
-  static const char pathSeparator = '/';
 #endif
 
 using namespace ignition;
@@ -121,8 +112,7 @@ class ignition::common::ColladaExporterPrivate
   /// \param[in] _libraryVisualScenesXml Pointer to the library visual
   /// scenes XML instance
   public: void ExportVisualScenes(
-              tinyxml2::XMLElement *_libraryVisualScenesXml,
-              const std::vector<math::Matrix4d> &_submeshToMatrix);
+              tinyxml2::XMLElement *_libraryVisualScenesXml);
 
   /// \brief Export scene element
   /// \param[in] _sceneXml Pointer to the scene XML instance
@@ -163,23 +153,6 @@ ColladaExporter::~ColladaExporter()
 void ColladaExporter::Export(const Mesh *_mesh, const std::string &_filename,
     bool _exportTextures)
 {
-  std::vector<math::Matrix4d> empty;
-  this->Export(_mesh, _filename, _exportTextures, empty);
-}
-
-//////////////////////////////////////////////////
-void ColladaExporter::Export(const Mesh *_mesh, const std::string &_filename,
-    bool _exportTextures, const std::vector<math::Matrix4d> &_submeshToMatrix)
-{
-  if ( _submeshToMatrix.size() > 0 &&
-    (_mesh->SubMeshCount() != _submeshToMatrix.size()) )
-  {
-    ignerr << "_submeshToMatrix.size() : " << _mesh->SubMeshCount()
-        << " , must be equal to SubMeshCount() : " << _mesh->SubMeshCount()
-        << std::endl;
-    return;
-  }
-
   this->dataPtr->mesh = _mesh;
   this->dataPtr->materialCount = this->dataPtr->mesh->MaterialCount();
   this->dataPtr->subMeshCount = this->dataPtr->mesh->SubMeshCount();
@@ -192,6 +165,14 @@ void ColladaExporter::Export(const Mesh *_mesh, const std::string &_filename,
   this->dataPtr->path = unix_filename.substr(0, beginFilename);
   this->dataPtr->filename = unix_filename.substr(beginFilename);
 
+  if (this->dataPtr->materialCount != 0 &&
+      this->dataPtr->materialCount != this->dataPtr->subMeshCount)
+  {
+    ignwarn << "Material count [" << this->dataPtr->materialCount <<
+        "] different from submesh count [" <<
+        this->dataPtr->subMeshCount << "]\n";
+  }
+
   // Collada file
   tinyxml2::XMLDocument xmlDoc;
 
@@ -242,7 +223,7 @@ void ColladaExporter::Export(const Mesh *_mesh, const std::string &_filename,
   // Library visual scenes element
   tinyxml2::XMLElement *libraryVisualScenesXml =
       xmlDoc.NewElement("library_visual_scenes");
-  this->dataPtr->ExportVisualScenes(libraryVisualScenesXml, _submeshToMatrix);
+  this->dataPtr->ExportVisualScenes(libraryVisualScenesXml);
   colladaXml->LinkEndChild(libraryVisualScenesXml);
 
   // Scene element
@@ -342,7 +323,7 @@ void ColladaExporterPrivate::ExportGeometrySource(
     ignition::math::Vector2d inTexCoord;
     for (unsigned int i = 0; i < count; ++i)
     {
-      inTexCoord = _subMesh->TexCoordBySet(i, 0);
+      inTexCoord = _subMesh->TexCoord(i);
       fillData << inTexCoord.X() << " " << 1-inTexCoord.Y() << " ";
     }
   }
@@ -409,12 +390,9 @@ void ColladaExporterPrivate::ExportGeometries(
 {
   for (unsigned int i = 0; i < this->subMeshCount; ++i)
   {
-    unsigned int materialIndex =
-      this->mesh->SubMeshByIndex(i).lock()->MaterialIndex();
-
     char meshId[100], materialId[100];
     snprintf(meshId, sizeof(meshId), "mesh_%u", i);
-    snprintf(materialId, sizeof(materialId), "material_%u", materialIndex);
+    snprintf(materialId, sizeof(materialId), "material_%u", i);
 
     tinyxml2::XMLElement *geometryXml =
       _libraryGeometriesXml->GetDocument()->NewElement("geometry");
@@ -431,7 +409,7 @@ void ColladaExporterPrivate::ExportGeometries(
 
     this->ExportGeometrySource(subMesh.get(), meshXml, POSITION, meshId);
     this->ExportGeometrySource(subMesh.get(), meshXml, NORMAL, meshId);
-    if (subMesh->TexCoordCountBySet(0) != 0)
+    if (subMesh->TexCoordCount() != 0)
     {
       this->ExportGeometrySource(subMesh.get(), meshXml, UVMAP, meshId);
     }
@@ -477,7 +455,7 @@ void ColladaExporterPrivate::ExportGeometries(
     snprintf(attributeValue, sizeof(attributeValue), "#%s-Normals", meshId);
     inputXml->SetAttribute("source", attributeValue);
 
-    if (subMesh->TexCoordCountBySet(0) != 0)
+    if (subMesh->TexCoordCount() != 0)
     {
       inputXml = _libraryGeometriesXml->GetDocument()->NewElement("input");
       trianglesXml->LinkEndChild(inputXml);
@@ -491,7 +469,7 @@ void ColladaExporterPrivate::ExportGeometries(
     for (unsigned int j = 0; j < indexCount; ++j)
     {
       fillData << subMesh->Index(j) << " " << subMesh->Index(j) << " ";
-      if (subMesh->TexCoordCountBySet(0) != 0)
+      if (subMesh->TexCoordCount() != 0)
       {
         fillData << subMesh->Index(j) << " ";
       }
@@ -516,7 +494,7 @@ int ColladaExporterPrivate::ExportImages(
       this->mesh->MaterialByIndex(i);
     std::string imageString = material->TextureImage();
 
-    if (imageString.find(pathSeparator) != std::string::npos)
+    if (imageString.find("meshes/") != std::string::npos)
     {
       char id[100];
       snprintf(id, sizeof(id), "image_%u", i);
@@ -528,22 +506,19 @@ int ColladaExporterPrivate::ExportImages(
 
       tinyxml2::XMLElement *initFromXml =
         _libraryImagesXml->GetDocument()->NewElement("init_from");
-      const auto imageName = imageString.substr(
-          imageString.rfind(pathSeparator));
-      const auto imagePath = ignition::common::joinPaths("..", "materials",
-        "textures", imageName);
-      initFromXml->LinkEndChild(
-        _libraryImagesXml->GetDocument()->NewText(imagePath.c_str()));
+      initFromXml->LinkEndChild(_libraryImagesXml->GetDocument()->NewText(
+        imageString.substr(imageString.find("meshes/")+7).c_str()));
       imageXml->LinkEndChild(initFromXml);
 
       if (this->exportTextures)
       {
-        std::string textureDir = joinPaths(this->path, this->filename,
-            "materials", "textures");
-        std::string destFilename = joinPaths(textureDir, imageString.substr(
-              imageString.rfind(pathSeparator)));
-        createDirectories(textureDir);
-        copyFile(imageString, destFilename);
+        createDirectories(this->path + this->filename + "/materials/textures");
+
+        std::ifstream  src(imageString.c_str(), std::ios::binary);
+        std::ofstream  dst((this->path + this->filename +
+            "/materials/textures" + imageString.substr(
+            imageString.rfind("/"))).c_str(), std::ios::binary);
+        dst << src.rdbuf();
       }
 
       imageCount++;
@@ -598,7 +573,7 @@ void ColladaExporterPrivate::ExportEffects(
         this->mesh->MaterialByIndex(i);
     std::string imageString = material->TextureImage();
 
-    if (imageString.find(pathSeparator) != std::string::npos)
+    if (imageString.find("meshes/") != std::string::npos)
     {
       tinyxml2::XMLElement *newParamXml =
         _libraryEffectsXml->GetDocument()->NewElement("newparam");
@@ -693,11 +668,11 @@ void ColladaExporterPrivate::ExportEffects(
       _libraryEffectsXml->GetDocument()->NewElement("diffuse");
     phongXml->LinkEndChild(diffuseXml);
 
-    if (imageString.find(pathSeparator) != std::string::npos)
+    if (imageString.find("meshes/") != std::string::npos)
     {
       tinyxml2::XMLElement *textureXml =
         _libraryEffectsXml->GetDocument()->NewElement("texture");
-      snprintf(id, sizeof(id), "image_%u_sampler", i);
+      snprintf(id, sizeof(id), "image_%u", i);
       textureXml->SetAttribute("texture", id);
       textureXml->SetAttribute("texcoord", "UVSET0");
       diffuseXml->LinkEndChild(textureXml);
@@ -733,9 +708,7 @@ void ColladaExporterPrivate::ExportEffects(
     specularXml->LinkEndChild(colorXml);
 
     // transparency
-    // In Collada, a transparency value of 1 is not transparent and 0 is
-    // fully transparent.
-    double transp = 1.0 - material->Transparency();
+    double transp = material->Transparency();
 
     tinyxml2::XMLElement *transparencyXml =
       _libraryEffectsXml->GetDocument()->NewElement("transparency");
@@ -763,8 +736,7 @@ void ColladaExporterPrivate::ExportEffects(
 
 //////////////////////////////////////////////////
 void ColladaExporterPrivate::ExportVisualScenes(
-    tinyxml2::XMLElement *_libraryVisualScenesXml,
-    const std::vector<math::Matrix4d> &_submeshToMatrix)
+    tinyxml2::XMLElement *_libraryVisualScenesXml)
 {
   tinyxml2::XMLElement *visualSceneXml =
     _libraryVisualScenesXml->GetDocument()->NewElement("visual_scene");
@@ -772,34 +744,17 @@ void ColladaExporterPrivate::ExportVisualScenes(
   visualSceneXml->SetAttribute("name", "Scene");
   visualSceneXml->SetAttribute("id", "Scene");
 
+  tinyxml2::XMLElement *nodeXml =
+    _libraryVisualScenesXml->GetDocument()->NewElement("node");
+  visualSceneXml->LinkEndChild(nodeXml);
+  nodeXml->SetAttribute("name", "node");
+  nodeXml->SetAttribute("id", "node");
+
   for (unsigned int i = 0; i < this->subMeshCount; ++i)
   {
-    char meshId[100], attributeValue[101], nodeId[106];
-
+    char meshId[100], materialId[100], attributeValue[101];
     snprintf(meshId, sizeof(meshId), "mesh_%u", i);
-    snprintf(nodeId, sizeof(nodeId), "node_%u", i);
-
-    tinyxml2::XMLElement *nodeXml =
-      _libraryVisualScenesXml->GetDocument()->NewElement("node");
-    visualSceneXml->LinkEndChild(nodeXml);
-
-    nodeXml->SetAttribute("name", nodeId);
-    nodeXml->SetAttribute("id", nodeId);
-
-    if (i < _submeshToMatrix.size())
-    {
-      std::ostringstream fillData;
-      fillData.precision(8);
-      fillData << std::fixed;
-
-      fillData << _submeshToMatrix.at(i);
-
-      tinyxml2::XMLElement *matrixXml =
-        _libraryVisualScenesXml->GetDocument()->NewElement("matrix");
-      nodeXml->LinkEndChild(matrixXml);
-      matrixXml->LinkEndChild(_libraryVisualScenesXml->GetDocument()->NewText(
-            fillData.str().c_str()));
-    }
+    snprintf(materialId, sizeof(materialId), "material_%u", i);
 
     tinyxml2::XMLElement *instanceGeometryXml =
       _libraryVisualScenesXml->GetDocument()->NewElement("instance_geometry");
@@ -807,18 +762,11 @@ void ColladaExporterPrivate::ExportVisualScenes(
     snprintf(attributeValue, sizeof(attributeValue), "#%s", meshId);
     instanceGeometryXml->SetAttribute("url", attributeValue);
 
-    unsigned int materialIndex =
-      this->mesh->SubMeshByIndex(i).lock()->MaterialIndex();
-
     const ignition::common::MaterialPtr material =
-      this->mesh->MaterialByIndex(materialIndex);
+      this->mesh->MaterialByIndex(i);
 
     if (material)
     {
-      char materialId[100];
-
-      snprintf(materialId, sizeof(materialId), "material_%u", materialIndex);
-
       tinyxml2::XMLElement *bindMaterialXml =
         _libraryVisualScenesXml->GetDocument()->NewElement("bind_material");
       instanceGeometryXml->LinkEndChild(bindMaterialXml);
@@ -836,7 +784,7 @@ void ColladaExporterPrivate::ExportVisualScenes(
 
       std::string imageString = material->TextureImage();
 
-      if (imageString.find(pathSeparator) != std::string::npos)
+      if (imageString.find("meshes/") != std::string::npos)
       {
         tinyxml2::XMLElement *bindVertexInputXml =
           _libraryVisualScenesXml->GetDocument()->NewElement(
