@@ -316,9 +316,8 @@ namespace ignition
       /// \brief Index of a normal in the collada <p> element
       public: unsigned int normalIndex;
 
-      /// \brief A map of texture coordinate set index to index of a texture
-      /// coordinate in the collada <p> element
-      public: std::map<unsigned int, unsigned int> texcoordIndex;
+      /// \brief Index of a texture coordinate in the collada <p> element
+      public: unsigned int texcoordIndex;
 
       /// \brief Index of a vertex in the Gazebo mesh
       public: unsigned int mappedIndex;
@@ -389,13 +388,9 @@ Mesh *ColladaLoader::Load(const std::string &_filename)
   tinyxml2::XMLDocument xmlDoc;
 
   this->dataPtr->path.clear();
-  std::string separator("/");
-#ifdef WIN32
-  separator = std::string("\\");
-#endif
-  if (_filename.rfind(separator) != std::string::npos)
+  if (_filename.rfind('/') != std::string::npos)
   {
-    this->dataPtr->path = _filename.substr(0, _filename.rfind(separator));
+    this->dataPtr->path = _filename.substr(0, _filename.rfind('/'));
   }
 
   this->dataPtr->filename = _filename;
@@ -471,6 +466,11 @@ void ColladaLoaderPrivate::LoadNode(tinyxml2::XMLElement *_elem, Mesh *_mesh,
   ignition::math::Matrix4d transform = this->LoadNodeTransform(_elem);
   transform = _transform * transform;
 
+  if (_elem->Attribute("name"))
+  {
+    this->currentNodeName = _elem->Attribute("name");
+  }
+
   nodeXml = _elem->FirstChildElement("node");
   while (nodeXml)
   {
@@ -478,36 +478,6 @@ void ColladaLoaderPrivate::LoadNode(tinyxml2::XMLElement *_elem, Mesh *_mesh,
     nodeXml = nodeXml->NextSiblingElement("node");
   }
 
-  if (_elem->Attribute("name"))
-  {
-    this->currentNodeName = _elem->Attribute("name");
-  }
-  else
-  {
-    // if node does not have a name, then append the mesh in this node
-    // to the first ancestor node that has a name, i.e. this mesh becomes
-    // part of the parent / ancestor mesh
-    tinyxml2::XMLElement *parent =
-        dynamic_cast<tinyxml2::XMLElement *>(_elem->Parent());
-    std::string nodeName;
-    while (parent && std::string(parent->Value()) == "node")
-    {
-      const char *name = parent->Attribute("name");
-      if (name)
-      {
-        nodeName = name;
-        break;
-      }
-    }
-    if (nodeName.empty())
-    {
-      // if none of the ancestor node has a name, then create a custom name
-      static int nodeCounter = 0;
-      nodeName = "unnamed_submesh_" + std::to_string(nodeCounter++);
-    }
-    this->currentNodeName = nodeName;
-  }
-
   if (_elem->FirstChildElement("instance_node"))
   {
     std::string nodeURLStr =
@@ -1997,8 +1967,7 @@ void ColladaLoaderPrivate::LoadPolylist(tinyxml2::XMLElement *_polylistXml,
 
   std::vector<ignition::math::Vector3d> verts;
   std::vector<ignition::math::Vector3d> norms;
-  std::map<unsigned int, std::vector<ignition::math::Vector2d>> texcoords;
-  std::vector<std::pair<unsigned int, unsigned int>> texcoordsOffsetToSet;
+  std::vector<ignition::math::Vector2d> texcoords;
 
   const unsigned int VERTEX = 0;
   const unsigned int NORMAL = 1;
@@ -2006,8 +1975,7 @@ void ColladaLoaderPrivate::LoadPolylist(tinyxml2::XMLElement *_polylistXml,
   unsigned int otherSemantics = TEXCOORD + 1;
 
   // look up table of position/normal/texcoord duplicate indices
-  std::unordered_map<unsigned int, std::map<unsigned int, unsigned int>>
-      texDupMap;
+  std::map<unsigned int, unsigned int> texDupMap;
   std::map<unsigned int, unsigned int> normalDupMap;
   std::map<unsigned int, unsigned int> positionDupMap;
 
@@ -2041,14 +2009,8 @@ void ColladaLoaderPrivate::LoadPolylist(tinyxml2::XMLElement *_polylistXml,
     }
     else if (semantic == "TEXCOORD")
     {
-      int offsetInt = ignition::math::parseInt(offset);
-      unsigned int set = 0u;
-      auto setStr = polylistInputXml->Attribute("set");
-      if (setStr)
-        set = ignition::math::parseInt(setStr);
-      this->LoadTexCoords(source, texcoords[set], texDupMap[set]);
-      inputs[TEXCOORD].insert(offsetInt);
-      texcoordsOffsetToSet.push_back(std::make_pair(offsetInt, set));
+      this->LoadTexCoords(source, texcoords, texDupMap);
+      inputs[TEXCOORD].insert(ignition::math::parseInt(offset));
     }
     else
     {
@@ -2166,27 +2128,16 @@ void ColladaLoaderPrivate::LoadPolylist(tinyxml2::XMLElement *_polylistXml,
 
               if (!inputs[TEXCOORD].empty())
               {
-                texEqual = true;
-                for (auto &pair : texcoordsOffsetToSet)
-                {
-                  unsigned int offset = pair.first;
-                  unsigned int set = pair.second;
-                  // Get the vertex texcoord index value. If the texcoord is a
-                  // duplicate then reset the index to the first instance of the
-                  // duplicated texcoord
-                  unsigned int remappedTexcoordIndex =
-                    values[offset];
-                  auto &texDupMapSet = texDupMap[set];
-                  auto texDupMapSetIt = texDupMapSet.find(
-                      remappedTexcoordIndex);
-                  if (texDupMapSetIt != texDupMapSet.end())
-                    remappedTexcoordIndex = texDupMapSetIt->second;
-                  if (iv.texcoordIndex[set] != remappedTexcoordIndex)
-                  {
-                    texEqual = false;
-                    break;
-                  }
-                }
+                // Get the vertex texcoord index value. If the texcoord is a
+                // duplicate then reset the index to the first instance of the
+                // duplicated texcoord
+                unsigned int remappedTexcoordIndex =
+                  values[*inputs[TEXCOORD].begin()];
+
+                if (texDupMap.find(remappedTexcoordIndex) != texDupMap.end())
+                  remappedTexcoordIndex = texDupMap[remappedTexcoordIndex];
+
+                texEqual = iv.texcoordIndex == remappedTexcoordIndex;
               }
 
               // if the vertex has matching normal and texcoord index values
@@ -2252,25 +2203,17 @@ void ColladaLoaderPrivate::LoadPolylist(tinyxml2::XMLElement *_polylistXml,
 
           if (!inputs[TEXCOORD].empty())
           {
-            for (auto &pair : texcoordsOffsetToSet)
+            unsigned int inputRemappedTexcoordIndex =
+              values[*inputs[TEXCOORD].begin()];
+
+            if (texDupMap.find(inputRemappedTexcoordIndex) != texDupMap.end())
             {
-              unsigned int offset = pair.first;
-              unsigned int set = pair.second;
-
-              unsigned int inputRemappedTexcoordIndex =
-                values[offset];
-
-              auto &texDupMapSet = texDupMap[set];
-              auto texDupMapSetIt = texDupMapSet.find(
-                  inputRemappedTexcoordIndex);
-              if (texDupMapSetIt != texDupMapSet.end())
-                inputRemappedTexcoordIndex = texDupMapSetIt->second;
-              auto &texcoordsSet = texcoords[set];
-              subMesh->AddTexCoordBySet(
-                  texcoordsSet[inputRemappedTexcoordIndex].X(),
-                  texcoordsSet[inputRemappedTexcoordIndex].Y(), set);
-              input.texcoordIndex[set] = inputRemappedTexcoordIndex;
+              inputRemappedTexcoordIndex =
+                  texDupMap[inputRemappedTexcoordIndex];
             }
+            subMesh->AddTexCoord(texcoords[inputRemappedTexcoordIndex].X(),
+                texcoords[inputRemappedTexcoordIndex].Y());
+            input.texcoordIndex = inputRemappedTexcoordIndex;
           }
 
           // add the new ignition submesh vertex index to the map
@@ -2325,8 +2268,7 @@ void ColladaLoaderPrivate::LoadTriangles(tinyxml2::XMLElement *_trianglesXml,
 
   std::vector<ignition::math::Vector3d> verts;
   std::vector<ignition::math::Vector3d> norms;
-  std::map<unsigned int, std::vector<ignition::math::Vector2d>> texcoords;
-  std::vector<std::pair<unsigned int, unsigned int>> texcoordsOffsetToSet;
+  std::vector<ignition::math::Vector2d> texcoords;
 
   const unsigned int VERTEX = 0;
   const unsigned int NORMAL = 1;
@@ -2342,8 +2284,7 @@ void ColladaLoaderPrivate::LoadTriangles(tinyxml2::XMLElement *_trianglesXml,
   std::map<const unsigned int, std::set<int>> inputs;
 
   // look up table of position/normal/texcoord duplicate indices
-  std::unordered_map<unsigned int, std::map<unsigned int, unsigned int>>
-      texDupMap;
+  std::map<unsigned int, unsigned int> texDupMap;
   std::map<unsigned int, unsigned int> normalDupMap;
   std::map<unsigned int, unsigned int> positionDupMap;
 
@@ -2371,14 +2312,9 @@ void ColladaLoaderPrivate::LoadTriangles(tinyxml2::XMLElement *_trianglesXml,
     }
     else if (semantic == "TEXCOORD")
     {
-      int offsetInt = ignition::math::parseInt(offset);
-      unsigned int set = 0u;
-      auto setStr = trianglesInputXml->Attribute("set");
-      if (setStr)
-        set = ignition::math::parseInt(setStr);
-      this->LoadTexCoords(source, texcoords[set], texDupMap[set]);
-      inputs[TEXCOORD].insert(offsetInt);
-      texcoordsOffsetToSet.push_back(std::make_pair(offsetInt, set));
+      // we currently only support one set of UVs
+      this->LoadTexCoords(source, texcoords, texDupMap);
+      inputs[TEXCOORD].insert(ignition::math::parseInt(offset));
       hasTexcoords = true;
     }
     else
@@ -2490,28 +2426,16 @@ void ColladaLoaderPrivate::LoadTriangles(tinyxml2::XMLElement *_trianglesXml,
           }
           if (hasTexcoords)
           {
-            texEqual = true;
-            for (auto &pair : texcoordsOffsetToSet)
-            {
-              unsigned int offset = pair.first;
-              unsigned int set = pair.second;
+            // Get the vertex texcoord index value. If the texcoord is a
+            // duplicate then reset the index to the first instance of the
+            // duplicated texcoord
+            unsigned int remappedTexcoordIndex =
+                values.at(*inputs[TEXCOORD].begin());
+            if (texDupMap.find(remappedTexcoordIndex) != texDupMap.end())
+              remappedTexcoordIndex = texDupMap[remappedTexcoordIndex];
 
-              // Get the vertex texcoord index value. If the texcoord is a
-              // duplicate then reset the index to the first instance of the
-              // duplicated texcoord
-              unsigned int remappedTexcoordIndex =
-                  values.at(offset);
-              auto &texDupMapSet = texDupMap[set];
-              auto texDupMapSetIt = texDupMapSet.find(remappedTexcoordIndex);
-              if (texDupMapSetIt != texDupMapSet.end())
-                remappedTexcoordIndex = texDupMapSetIt->second;
-
-              if (iv.texcoordIndex[set] != remappedTexcoordIndex)
-              {
-                texEqual = false;
-                break;
-              }
-            }
+            if (iv.texcoordIndex == remappedTexcoordIndex)
+              texEqual = true;
           }
 
           // if the vertex has matching normal and texcoord index values then
@@ -2575,24 +2499,13 @@ void ColladaLoaderPrivate::LoadTriangles(tinyxml2::XMLElement *_trianglesXml,
       }
       if (hasTexcoords)
       {
-        for (auto &pair : texcoordsOffsetToSet)
-        {
-          unsigned int offset = pair.first;
-          unsigned int set = pair.second;
-
-          unsigned int inputRemappedTexcoordIndex =
-              values.at(offset);
-
-          auto &texDupMapSet = texDupMap[set];
-          auto texDupMapSetIt = texDupMapSet.find(inputRemappedTexcoordIndex);
-          if (texDupMapSetIt != texDupMapSet.end())
-            inputRemappedTexcoordIndex = texDupMapSetIt->second;
-          auto &texcoordsSet = texcoords[set];
-          subMesh->AddTexCoordBySet(
-              texcoordsSet[inputRemappedTexcoordIndex].X(),
-              texcoordsSet[inputRemappedTexcoordIndex].Y(), set);
-          input.texcoordIndex[set] = inputRemappedTexcoordIndex;
-        }
+        unsigned int inputRemappedTexcoordIndex =
+            values.at(*inputs[TEXCOORD].begin());
+        if (texDupMap.find(inputRemappedTexcoordIndex) != texDupMap.end())
+          inputRemappedTexcoordIndex = texDupMap[inputRemappedTexcoordIndex];
+        subMesh->AddTexCoord(texcoords[inputRemappedTexcoordIndex].X(),
+            texcoords[inputRemappedTexcoordIndex].Y());
+        input.texcoordIndex = inputRemappedTexcoordIndex;
       }
 
       // add the new ignition submesh vertex index to the map
@@ -2697,15 +2610,6 @@ void ColladaLoaderPrivate::LoadTransparent(tinyxml2::XMLElement *_elem,
     double srcFactor = 0;
     double dstFactor = 0;
 
-    // If <transparency> tag exists, _mat->Transparency() should be set to
-    // that value already. Otherwise, use default value of 1.0 as per
-    // collada spec
-    double transparency = 1.0;
-    auto transparencyNode =
-        _elem->Parent()->FirstChildElement("transparency");
-    if (transparencyNode)
-      transparency = _mat->Transparency();
-
     // Calculate alpha based on opaque mode.
     // Equations are extracted from collada spec
     // Make sure to update the final transparency value
@@ -2720,8 +2624,8 @@ void ColladaLoaderPrivate::LoadTransparent(tinyxml2::XMLElement *_elem,
       // (1.0f - luminance(transparent.rgb) * transparency)
       // where fb corresponds to the framebuffer (existing pixel) and
       // mat corresponds to material before transparency (texel)
-      dstFactor = luminance * transparency;
-      srcFactor = 1.0 - luminance * transparency;
+      dstFactor = luminance * _mat->Transparency();
+      srcFactor = 1.0 - luminance * _mat->Transparency();
       _mat->SetTransparency(dstFactor);
     }
     else if (opaqueStr == "RGB_ONE")
@@ -2735,8 +2639,8 @@ void ColladaLoaderPrivate::LoadTransparent(tinyxml2::XMLElement *_elem,
       // mat.a * (luminance(transparent.rgb) * transparency)
       // where fb corresponds to the framebuffer (existing pixel) and
       // mat corresponds to material before transparency (texel)
-      dstFactor = 1.0 - luminance * transparency;
-      srcFactor = luminance * transparency;
+      dstFactor = 1.0 - luminance * _mat->Transparency();
+      srcFactor = luminance * _mat->Transparency();
       _mat->SetTransparency(dstFactor);
     }
     else if (opaqueStr == "A_ONE")
@@ -2745,8 +2649,8 @@ void ColladaLoaderPrivate::LoadTransparent(tinyxml2::XMLElement *_elem,
       // (transparent.a * transparency)
       // where fb corresponds to the framebuffer (existing pixel) and
       // mat corresponds to material before transparency (texel)
-      dstFactor = 1.0 - color.A() * transparency;
-      srcFactor = color.A() * transparency;
+      dstFactor = 1.0 - color.A() * _mat->Transparency();
+      srcFactor = color.A() * _mat->Transparency();
       _mat->SetTransparency(dstFactor);
     }
     else if (opaqueStr == "A_ZERO")
@@ -2755,8 +2659,8 @@ void ColladaLoaderPrivate::LoadTransparent(tinyxml2::XMLElement *_elem,
       // (1.0f - transparent.a * transparency)
       // where fb corresponds to the framebuffer (existing pixel) and
       // mat corresponds to material before transparency (texel)
-      dstFactor = color.A() * transparency;
-      srcFactor = 1.0 - color.A() * transparency;
+      dstFactor = color.A() * _mat->Transparency();
+      srcFactor = 1.0 - color.A() * _mat->Transparency();
       _mat->SetTransparency(dstFactor);
     }
 
