@@ -822,237 +822,6 @@ void MeshManager::CreateCamera(const std::string &_name, float _scale)
   mesh->RecalculateNormals();
 }
 
-//////////////////////////////////////////////////
-void MeshManager::CreateEllipsoid(const std::string &_name,
-                                  const ignition::math::Vector3d &_radii,
-                                  const unsigned int _rings,
-                                  const unsigned int _segments)
-{
-  if (this->HasMesh(_name))
-  {
-    return;
-  }
-
-  Mesh *mesh = new Mesh();
-  mesh->SetName(_name);
-  this->dataPtr->meshes.insert(std::make_pair(_name, mesh));
-
-  SubMesh subMesh;
-
-  const double umin = -IGN_PI / 2.0;
-  const double umax = IGN_PI / 2.0;
-  const double vmin = 0.0;
-  const double vmax = 2.0 * IGN_PI;
-
-  unsigned int i, j;
-  double theta, phi;
-  double d_phi = (umax - umin) / (_rings - 1.0);
-  double d_theta = (vmax - vmin) / (_segments - 1.0);
-
-  for (i = 0, theta = vmin; i < _rings; ++i, theta += d_theta)
-  {
-    const auto c_theta = cos(theta);
-    const auto s_theta = sin(theta);
-
-    for (j = 0, phi = umin; j < _segments; ++j, phi += d_phi)
-    {
-      const auto c_phi = cos(phi);
-      const auto s_phi = sin(phi);
-
-      // Compute vertex
-      subMesh.AddVertex(ignition::math::Vector3d(
-        _radii.X() * c_phi * c_theta,
-        _radii.Y() * c_phi * s_theta,
-        _radii.Z() * s_phi));
-
-      // Compute unit normal at vertex
-      ignition::math::Vector3d du(
-        -(_radii.X() * c_phi) * s_theta,
-        +(_radii.Y() * c_phi) * c_theta,
-        0.0);
-      ignition::math::Vector3d dv(
-        -_radii.X() * s_phi * c_theta,
-        -_radii.Y() * s_phi * s_theta,
-        _radii.Z() * c_phi);
-
-      ignition::math::Vector3d normal = du.Cross(dv);
-
-      subMesh.AddNormal(normal);
-
-      if (i > 0)
-      {
-        unsigned int verticesCount = subMesh.VertexCount();
-        for (
-          int firstIndex = verticesCount - 2 * (_segments + 1);
-          (firstIndex + _segments + 2 < verticesCount) && (firstIndex > 0);
-          firstIndex++)
-        {
-          subMesh.AddIndex(firstIndex + _segments + 1);
-          subMesh.AddIndex(firstIndex + 1);
-          subMesh.AddIndex(firstIndex + 0);
-
-          subMesh.AddIndex(firstIndex + _segments + 2);
-          subMesh.AddIndex(firstIndex + 1);
-          subMesh.AddIndex(firstIndex + _segments + 1);
-        }
-      }
-    }
-  }
-  mesh->AddSubMesh(subMesh);
-}
-
-//////////////////////////////////////////////////
-void MeshManager::CreateCapsule(const std::string &_name,
-                                const double _radius,
-                                const double _length,
-                                const unsigned int _rings,
-                                const unsigned int _segments)
-{
-  if (this->HasMesh(_name))
-  {
-    return;
-  }
-
-  Mesh *mesh = new Mesh();
-  mesh->SetName(_name);
-  this->dataPtr->meshes.insert(std::make_pair(_name, mesh));
-
-  SubMesh subMesh;
-
-  // Based on https://github.com/godotengine/godot primitive_meshes.cpp
-  int prevRow, thisRow, point;
-  double x, y, z, u, v, w;
-  const double oneThird = 1.0 / 3.0;
-  const double twoThirds = 2.0 / 3.0;
-
-  point = 0;
-
-  /* top hemisphere */
-  thisRow = 0;
-  prevRow = 0;
-  for (unsigned int j = 0; j <= (_rings + 1); j++) {
-    v = j;
-
-    v /= (_rings + 1);
-    w = sin(0.5 * IGN_PI * v);
-    y = _radius * cos(0.5 * IGN_PI * v);
-
-    for (unsigned int i = 0; i <= _segments; i++) {
-      u = i;
-      u /= _segments;
-
-      x = -sin(u * (IGN_PI * 2.0));
-      z = cos(u * (IGN_PI * 2.0));
-
-      ignition::math::Vector3d p(
-      x * _radius * w, y, -z * _radius * w);
-      // Compute vertex
-      subMesh.AddVertex(ignition::math::Vector3d(
-        p + ignition::math::Vector3d(0.0, 0.5 * _length, 0.0)));
-      subMesh.AddTexCoord({u, v * oneThird});
-      subMesh.AddNormal(p.Normalize());
-
-      point++;
-
-      if (i > 0 && j > 0) {
-        subMesh.AddIndex(thisRow + i - 1);
-        subMesh.AddIndex(prevRow + i);
-        subMesh.AddIndex(prevRow + i - 1);
-
-        subMesh.AddIndex(thisRow + i - 1);
-        subMesh.AddIndex(thisRow + i);
-        subMesh.AddIndex(prevRow + i);
-      }
-    }
-    prevRow = thisRow;
-    thisRow = point;
-  }
-
-  /* cylinder */
-  thisRow = point;
-  prevRow = 0;
-  for (unsigned int j = 0; j <= (_rings + 1); j++) {
-    v = j;
-    v /= (_rings + 1);
-
-    y = _length * v;
-    y = (_length * 0.5) - y;
-
-    for (unsigned int i = 0; i <= _segments; i++) {
-      u = i;
-      u /= _segments;
-
-      x = -sin(u * (IGN_PI * 2.0));
-      z = cos(u * (IGN_PI * 2.0));
-
-      ignition::math::Vector3d p(
-      x * _radius, y, -z * _radius);
-
-      // Compute vertex
-      subMesh.AddVertex(p);
-      subMesh.AddTexCoord({u, oneThird + (v * oneThird)});
-      subMesh.AddNormal(ignition::math::Vector3d(x, 0.0, -z));
-      point++;
-
-      if (i > 0 && j > 0) {
-        subMesh.AddIndex(thisRow + i - 1);
-        subMesh.AddIndex(prevRow + i);
-        subMesh.AddIndex(prevRow + i - 1);
-
-        subMesh.AddIndex(thisRow + i - 1);
-        subMesh.AddIndex(thisRow + i);
-        subMesh.AddIndex(prevRow + i);
-      }
-    }
-    prevRow = thisRow;
-    thisRow = point;
-  }
-
-  /* bottom hemisphere */
-  thisRow = point;
-  prevRow = 0;
-  for (unsigned int j = 0; j <= (_rings + 1); j++) {
-    v = j;
-
-    v /= (_rings + 1);
-    v += 1.0;
-    w = sin(0.5 * IGN_PI * v);
-    y = _radius * cos(0.5 * IGN_PI * v);
-
-    for (unsigned int i = 0; i <= _segments; i++) {
-      double u2 = static_cast<double>(i);
-      u2 /= _segments;
-
-      x = -sin(u2 * (IGN_PI * 2.0));
-      z = cos(u2 * (IGN_PI * 2.0));
-
-      ignition::math::Vector3d p(
-      x * _radius * w, y, -z * _radius * w);
-      // Compute vertex
-      subMesh.AddVertex(ignition::math::Vector3d(
-        p + ignition::math::Vector3d(0.0, -0.5 * _length, 0.0)));
-      subMesh.AddTexCoord({u2, twoThirds + ((v - 1.0) * oneThird)});
-      subMesh.AddNormal(p.Normalize());
-      point++;
-
-      if (i > 0 && j > 0) {
-        subMesh.AddIndex(thisRow + i - 1);
-        subMesh.AddIndex(prevRow + i);
-        subMesh.AddIndex(prevRow + i - 1);
-
-        subMesh.AddIndex(thisRow + i - 1);
-        subMesh.AddIndex(thisRow + i);
-        subMesh.AddIndex(prevRow + i);
-      }
-    }
-
-    prevRow = thisRow;
-    thisRow = point;
-  }
-
-  mesh->AddSubMesh(subMesh);
-}
-
 //////////////////////////////////////////////////
 void MeshManager::CreateCylinder(const std::string &name, float radius,
                                  float height, int rings, int segments)
