@@ -19,7 +19,6 @@
 #include <cstring>
 #include <list>
 #include <map>
-#include <regex>
 #include <string>
 
 #include "ignition/common/Console.hh"
@@ -43,8 +42,7 @@ class ignition::common::URIPathPrivate
   ///        an absolute path starting segment or not.
   public: bool IsStringAbsolute(const std::string &_path)
   {
-    return (_path.length() > 0 && _path[0] == '/') ||
-           (_path.length() > 1 && _path[1] == ':');
+    return _path.length() > 0 && _path[0] == '/';
   }
 };
 
@@ -116,16 +114,6 @@ bool URIPath::IsAbsolute() const
 /////////////////////////////////////////////////
 void URIPath::SetAbsolute(const bool _absolute)
 {
-  if (this->dataPtr->isAbsolute && !_absolute && !this->dataPtr->path.empty() &&
-      this->dataPtr->path.front().length() >= 2 &&
-      this->dataPtr->path.front()[1] == ':')
-  {
-    ignerr << "URIPath " << this->Str() << " cannot be set to represent a "
-              "relative path because it starts with a Windows drive "
-              "specifier." << std::endl;
-    return;
-  }
-
   this->dataPtr->isAbsolute = _absolute;
 }
 
@@ -153,11 +141,6 @@ void URIPath::PushFront(const std::string &_part)
     part = _part.substr(1);
     this->SetAbsolute();
   }
-  // Windows absolute path
-  else if (_part.length() >= 2 && _part[1] == ':')
-  {
-    this->SetAbsolute();
-  }
 
   if (part.find('/') != std::string::npos)
   {
@@ -190,11 +173,6 @@ void URIPath::PushBack(const std::string &_part)
     part = _part.substr(1);
     this->SetAbsolute();
   }
-  // Windows absolute path
-  else if (this->dataPtr->path.empty() && _part.size() >= 2 && _part[1] == ':')
-  {
-    this->SetAbsolute();
-  }
 
   if (part.find('/') != std::string::npos)
   {
@@ -227,13 +205,6 @@ const URIPath &URIPath::operator/=(const std::string &_part)
 std::string URIPath::Str(const std::string &_delim) const
 {
   std::string result(this->dataPtr->isAbsolute ? "/" : "");
-  // if the first element is a windows drive specifier, do not prepend the slash
-  if (!this->dataPtr->path.empty() && this->dataPtr->path.front().size() >= 2 &&
-    this->dataPtr->path.front()[1] == ':')
-  {
-    result = "";
-  }
-
   bool firstPart = true;
   for (auto const &part : this->dataPtr->path)
   {
@@ -605,13 +576,8 @@ URI::URI()
 URI::URI(const std::string &_str)
   : URI()
 {
-  std::string str = _str;
-  if ((str.size() > 7 && 0 == str.compare(0, 7, "http://")) ||
-      (str.size() > 8 && 0 == str.compare(0, 8, "https://")))
-  {
-    str = std::regex_replace(str, std::regex(R"(\\)"), "/");
-  }
-  this->Parse(_str);
+  if (!this->Parse(_str))
+    ignwarn << "Unable to parse URI [" << _str << "]. Ignoring." << std::endl;
 }
 
 /////////////////////////////////////////////////
